import bpy, os, tempfile

class ASSETBROWSER_OT_RenderThumbnail(bpy.types.Operator):
    bl_idname = "asset_browser.capture_viewport_thumbnail"
    bl_label = "Render Thumbnail"
    bl_description = "Render a thumbnail from the viewport and set it as the asset preview"
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        try:
            thumbnail_path = os.path.join(tempfile.gettempdir(), "viewport_thumbnail.png")
            current_scebe_path = bpy.context.scene.render.filepath
            bpy.context.scene.render.filepath = thumbnail_path
            bpy.ops.render.opengl(write_still=True)
            bpy.ops.ed.lib_id_load_custom_preview(filepath=thumbnail_path)
            # reset back to original scene path
            bpy.context.scene.render.filepath = current_scebe_path
        except Exception as e:
            self.report({'ERROR'}, f"Failed to capture thumbnail: {e}")
            return {'CANCELLED'}

        return {'FINISHED'}


def draw_render_thumbnail_button(self, context):
    layout = self.layout
    row = layout.row()
    row.operator("asset_browser.capture_viewport_thumbnail", text="Capture Thumbnail from Viewport", icon='RESTRICT_RENDER_OFF')


def register():
    bpy.types.ASSETBROWSER_PT_metadata_preview.append(draw_render_thumbnail_button)
    bpy.utils.register_class(ASSETBROWSER_OT_RenderThumbnail)


def unregister():
    bpy.types.ASSETBROWSER_PT_metadata_preview.remove(draw_render_thumbnail_button)
    bpy.utils.unregister_class(ASSETBROWSER_OT_RenderThumbnail)